#!/usr/bin/env python

from __future__ import division

import os
import sys
import argparse
import common

def makeMorph(cpos, fpos, morph):

    if cpos == fpos or fpos == '_':
        return morph

    new_morph = 'fpos=' + fpos
    if morph == '_':
        return new_morph
    return new_morph + '|' + morph


if __name__ == '__main__':
    parser = argparse.ArgumentParser(description='Create a conll09 data file out of multiple input files.')
    parser.add_argument('-g', help='conll06 gold file')
    parser.add_argument('-p', help='conll06 pred file (for predicted lemma)')
    parser.add_argument('-o', help='conll09 output')
    parser.add_argument('-m', help='marmot pred file')

    args = parser.parse_args()

    gold_sentences = common.readSentences(args.g, True)

    if not args.p:
        pred_sentences =[None] * len(gold_sentences)
    else:
        pred_sentences = common.readSentences(args.p, True)
    marmot_sentences = common.readSentences(args.m, True)

    assert len(gold_sentences) == len(pred_sentences)
    assert len(gold_sentences) == len(marmot_sentences)

    with open(args.o, 'w') as f:

        for sentence_index, (gold_sentence, pred_sentence, marmot_sentence) in enumerate(zip(gold_sentences, pred_sentences, marmot_sentences)):
            if not pred_sentence:
                pred_sentence = [None] * len(gold_sentence)

            assert len(gold_sentence) == len(pred_sentence)
            assert len(gold_sentence) == len(marmot_sentence)

            for token_index, (gold_token_string, pred_token_string, marmot_token_string) in enumerate(zip(gold_sentence, pred_sentence, marmot_sentence)):
                gold_token = common.makeToken(gold_token_string)

                if not pred_token_string:
                    pred_token = None
                else:
                    pred_token = common.makeToken(pred_token_string)
                    assert gold_token['form'] == pred_token['form']

                marmot_pos, marmot_feat = marmot_token_string.split()

                d = {}
                d['index'] = '%d_%d' % (sentence_index + 1, token_index + 1)


                d['form'] = gold_token['form']

                d['glemma'] = gold_token['lemma']

                if not pred_token:
                    d['plemma'] = '_'
                else:
                    d['plemma'] = pred_token['lemma']

                d['gpos'] = '_'
                d['ppos'] = marmot_pos
                d['gmorph'] = '_'
                d['pmorph'] = marmot_feat

                d['ghead'] = gold_token['head']
                d['phead'] = '_'

                d['gdeprel'] = gold_token['deprel']
                d['pdeprel'] = '_'

                print >> f, common.tokenToString09(d)
            print >> f

